@@ -13,7 +13,9 @@ gboolean properties_super_safe_moves (void);
 gboolean properties_safe_moves (void);
 gboolean properties_sound (void);
 gboolean properties_splats (void);
+gboolean properties_show_toolbar (void);
 gboolean properties_set_config (gint);
+gchar   *properties_theme_name (void);
 
 GConfClient *get_gconf_client (void);
 void initialize_gconf (int argc, char *argv[]);
@@ -24,6 +26,10 @@ void gconf_set_enable_sound (gboolean value);
 void gconf_set_enable_splats (gboolean value);
 void gconf_set_use_safe_moves (gboolean value);
 void gconf_set_use_super_safe_moves (gboolean value);
+void gconf_set_show_toolbar (gboolean value);
+
+gint save_window_geometry (GtkWidget *w, GdkEventConfigure *e, gpointer data);
+void set_window_geometry (GtkWidget *window);
 
 /**********************************************************************/
 
